@@ -12,8 +12,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import platform
-
 from platformio.compat import is_proxy_set
 
 
@@ -30,9 +28,8 @@ def get_core_dependencies():
 
 def get_pip_dependencies():
     core = [
-        'bottle == 0.12.*; python_version < "3.7"',
-        'bottle == 0.13.*; python_version >= "3.7"',
-        "click >=8.0.4, <9",
+        "bottle == 0.13.*",
+        "click >=8.0.4, <8.1.8",
         "colorama",
         "marshmallow == 3.*",
         "pyelftools >=0.27, <1",
@@ -45,19 +42,16 @@ def get_pip_dependencies():
     home = [
         # PIO Home requirements
         "ajsonrpc == 1.2.*",
-        "starlette >=0.19, <0.40",
-        'uvicorn == 0.16.0; python_version < "3.7"',
-        'uvicorn >=0.16, <0.31; python_version >= "3.7"',
+        "starlette >=0.19, <0.47",
+        "uvicorn >=0.16, <0.35",
         "wsproto == 1.*",
     ]
 
     extra = []
-
     # issue #4702; Broken "requests/charset_normalizer" on macOS ARM
-    if platform.system() == "Darwin" and "arm" in platform.machine().lower():
-        extra.append(
-            'chardet >= 3.0.2,<6; platform_system == "Darwin" and "arm" in platform_machine'
-        )
+    extra.append(
+        'chardet >= 3.0.2,<6; platform_system == "Darwin" and "arm" in platform_machine'
+    )
 
     # issue 4614: urllib3 v2.0 only supports OpenSSL 1.1.1+
     try:
